==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/autoattendant/AAActions.php <==
<?php 

require('../assets/inc/ldapConnect.php');
$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
$aaPath = (isset($_REQUEST['aaPath']) && strlen($_REQUEST['aaPath']) >=1 ) ? $_REQUEST['aaPath'] : NULL;

if ($mode === 'uploadWav') {
	$result = 0;
	$filePath = "$aaPath/";
	
	if (!file_exists($aaPath)) {
		mkdir($aaPath, 0777, true);
		chmod($aaPath, 0777);
	}
	
	$tmp_file = $_FILES['myfile']['tmp_name'];
	$filename = basename( $_FILES['myfile']['name']);
	
	$extn = explode('.',$filename);
	if ($extn[1] != 'wav') {
		echo "<script language='javascript' type='text/javascript'>window.top.window.stopUpload('0','0')</script>";
		exit();
	}
		
	foreach(glob("$aaPath/*.wav") as $file) {  
		$filelist[] = str_replace("$aaPath/",'',$file);
	}
	
	if (isset($filelist)) {
		if (in_array($filename, $filelist)) {
			$filename = str_replace('.wav','',$filename);
			$filename = $filename."_".date('dmYHis').".wav";
		}
	}
	
	$target_path = $filePath . $filename;
	$result = move_uploaded_file($tmp_file, $target_path);
	
    echo "<script language='javascript' type='text/javascript'>window.top.window.stopUpload(\"$result\",\"$filename\")</script>";
}


if ($mode === 'deleteWav') {
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1 ) ? $_REQUEST['wavFile'] : NULL;
	if ($wavFile) {
		$res = @unlink ("$aaPath/$wavFile") ? '1' : '0';
		echo $res;
	}
}

// Apply wav file
if ($mode === 'applyWav') {
	$error = 0; // 0 = OK, 1 = backup fail, 2 = copy fail
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1 ) ? $_REQUEST['wavFile'] : NULL;
	$backupWav = (isset($_REQUEST['backupWav']) && strlen($_REQUEST['backupWav']) >=1 ) ? $_REQUEST['backupWav'] : NULL;
	$aaSave = (isset($_REQUEST['aaSave']) && strlen($_REQUEST['aaSave']) >=1 ) ? $_REQUEST['aaSave'] : NULL;
	
	if ($backupWav) {	
		$backupres = rename("$aaPath/AAGreeting.wav", "$aaPath/$backupWav");
		if ($backupres != '1') {
			$error++;
		}
	}	
	
	if ($wavFile) {
		$applyres = copy("$aaPath/$wavFile", "$aaPath/AAGreeting.wav");
		if ($applyres != '1') {
			$error++;
		}
	}
	
	$company =  (strpos($aaPath, '-') !== false) ? str_replace('/SpliceCom/Mailbox/','', $aaPath) : 'global';
	$fh = fopen($company, 'w') or die("can't open file");
	fwrite($fh, $wavFile);
	fclose($fh);

	echo $error;
}


//Check for AAGreeting.wav
if ($mode === 'aaCheck') {
	$result = (file_exists("$aaPath/AAGreeting.wav")) ? '1' : '0';
	echo $result;
}



// download backup file
if (isset($_REQUEST['download_file']) && strlen($_REQUEST['download_file']) >=1) {
error_log ("backup file = " . $_REQUEST['download_file']);


ignore_user_abort(true);
set_time_limit(0);

$path = "$aaPath/";
$dl_file = preg_replace("([^\w\s\d\-_~,;:%\[\]\(\].]|[\.]{2,})", '', $_GET['download_file']);
$fullPath = $path.$dl_file;

if ($fd = fopen ($fullPath, "r")) {
    $fsize = filesize($fullPath);
    $path_parts = pathinfo($fullPath);
    header("Content-type: application/octet-stream");
    header("Content-Disposition: filename=\"".$path_parts["basename"]."\"");
    
    header("Content-length: $fsize");
    header("Cache-control: private");
	ob_flush(); flush();
    while(!feof($fd)) {
        $buffer = fread($fd, 2048);
        echo $buffer;
	ob_flush(); flush();
    }
}
fclose ($fd);
}

if ($mode === 'search') {
	
	$selected = (isset($_REQUEST['selected']) && strlen($_REQUEST['selected']) >=1 ) ? $_REQUEST['selected'] : NULL;
	$currentCompany = (isset($_REQUEST['currentCompany']) && strlen($_REQUEST['currentCompany']) >=2 ) ? $_REQUEST['currentCompany'] : '*';
	$values = '';
	
	if ($selected) {
		switch ($selected) {
		case 'users':
			$queryCn = "cn=users";
			$objectclass = "user";
			$filter = array('cn','telephonenumber');
			break;
		case 'departments':
			$queryCn = "cn=departments";
			$objectclass = "department";
			$filter = array('cn','telephonenumber');
			break;		
		}
		
		$sr=ldap_list($ds, $queryCn,"(&(objectclass=$objectclass)(company=$currentCompany))", $filter);
		$info = ldap_get_entries($ds, $sr);	$selectedEntries = array();
		for ($m=0; $m<$info['count']; $m++) {				
			
		$values .= $info[$m]['telephonenumber'][0] . ":" . $info[$m]['cn'][0] . " (" . $info[$m]['telephonenumber'][0]. ")" . ",";
		}
			$values = rtrim($values, ',');
			echo $values;
	}
}


if ($mode === 'usersdepartments') {
	
	$currentCompany = (isset($_REQUEST['currentCompany']) && strlen($_REQUEST['currentCompany']) >=2 ) ? $_REQUEST['currentCompany'] : '*';
	$users = $departments = array();
	
		$sr=ldap_list($ds, "cn=users","(&(objectclass=user)(company=$currentCompany))", array('cn','telephonenumber','company'));
		$info = ldap_get_entries($ds, $sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$usersCn[$info[$m]['telephonenumber'][0]] = $info[$m]['cn'][0];
		}
				
		$sr=ldap_list($ds, "cn=departments","(&(objectclass=department)(company=$currentCompany))", array('cn','telephonenumber','company'));
		$info = ldap_get_entries($ds, $sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$departmentsCn[$info[$m]['telephonenumber'][0]] = $info[$m]['cn'][0];
		}
				
		$response = array (
			'usersCn' => $usersCn,
			'departmentsCn'  => $departmentsCn
		);
		echo json_encode($response);
	}
	
	
if ($mode === 'wavCheck') {	
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1) ? $_REQUEST['wavFile'] : NULL;
	
	$tmp_name = $wavFile;
	$fp = fopen($tmp_name, 'r');
	fseek($fp, 20); $d = fread($fp, 18); $data = unpack('vfmt/vch/Vsr/Vdr/vbs/vbis/vext', $d);
	$format = array(0 => 'error', 1 => 'error', 2 => 'error', 3 => 'error', 4 => 'error', 5 => 'error', 0x0001 => 'PCM',0x0003 => 'IEEE Float',0x0006 => 'A-LAW',0x0007 => 'MuLAW',0xFFFE => 'Extensible',);
	$bit = rtrim($data['sr'],"0") * rtrim($data['dr'],"0");
	$chn = ($data['ch'] = 1) ? "Mono" : "Stereo";

	echo ($format[$data['fmt']] != "A-LAW" || $data['ch'] !=1 || $data['dr'] !=8000 || $bit !=64) ? 0 : 1;

}

?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/autoattendant/AAActions.php <==
<?php 

require('../assets/inc/ldapConnect.php');
$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
$aaPath = (isset($_REQUEST['aaPath']) && strlen($_REQUEST['aaPath']) >=1 ) ? $_REQUEST['aaPath'] : NULL;
$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : NULL;

if ($mode === 'uploadWav') {
	$result = 0;
	$filePath = "$aaPath/";
	
	if (!file_exists($aaPath)) {
		mkdir($aaPath, 0777, true);
		chmod($aaPath, 0777);
	}
	
	$tmp_file = $_FILES['myfile']['tmp_name'];
	$filename = basename( $_FILES['myfile']['name']);
	
	$extn = explode('.',$filename);
	if ($extn[1] != 'wav') {
		echo "<script language='javascript' type='text/javascript'>window.top.window.stopUpload('0','0')</script>";
		exit();
	}
		
	foreach(glob("$aaPath/*.wav") as $file) {  
		$filelist[] = str_replace("$aaPath/",'',$file);
	}
	
	if (isset($filelist)) {
		if (in_array($filename, $filelist)) {
			$filename = str_replace('.wav','',$filename);
			$filename = $filename."_".date('dmYHis').".wav";
		}
	}
	
	$target_path = $filePath . $filename;
	$result = move_uploaded_file($tmp_file, $target_path);
	
    echo "<script language='javascript' type='text/javascript'>window.top.window.stopUpload(\"$result\",\"$filename\")</script>";
}


if ($mode === 'deleteWav') {
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1 ) ? $_REQUEST['wavFile'] : NULL;
	if ($wavFile) {
		$res = @unlink ("$aaPath/$wavFile") ? '1' : '0';
		echo $res;
		if ($timestamp) audit ($timestamp, "[AutoAttendant] [Delete WAV] $wavFile", "Deleted WAV File $wavFile");			
	}
}

// Apply wav file
if ($mode === 'applyWav') {
	$error = 0; // 0 = OK, 1 = backup fail, 2 = copy fail
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1 ) ? $_REQUEST['wavFile'] : NULL;
	$backupWav = (isset($_REQUEST['backupWav']) && strlen($_REQUEST['backupWav']) >=1 ) ? $_REQUEST['backupWav'] : NULL;
	$aaSave = (isset($_REQUEST['aaSave']) && strlen($_REQUEST['aaSave']) >=1 ) ? $_REQUEST['aaSave'] : NULL;
	
	if ($backupWav) {	
		$backupres = rename("$aaPath/AAGreeting.wav", "$aaPath/$backupWav");
		audit ($timestamp, "[AutoAttendant] [Backup WAV]", "Backed Up AAGreeting.wav to $backupWav");			
		if ($backupres != '1') {
			$error++;
		}
	}	
	
	if ($wavFile) {
		$applyres = copy("$aaPath/$wavFile", "$aaPath/AAGreeting.wav");
		if ($applyres != '1') {
			$error++;
		}
	}
	
	$company =  (strpos($aaPath, '-') !== false) ? str_replace('/SpliceCom/Mailbox/','', $aaPath) : 'global';
	$fh = fopen($company, 'w') or die("can't open file");
	fwrite($fh, $wavFile);
	fclose($fh);

	echo $error;
	audit ($timestamp, "[AutoAttendant] [Apply WAV] $wavFile", "Applying WAV File $wavFile");			
}


//Check for AAGreeting.wav
if ($mode === 'aaCheck') {
	$result = (file_exists("$aaPath/AAGreeting.wav")) ? '1' : '0';
	echo $result;
}



// download backup file
if (isset($_REQUEST['download_file']) && strlen($_REQUEST['download_file']) >=1) {
error_log ("backup file = " . $_REQUEST['download_file']);
$timestamp = time();

ignore_user_abort(true);
set_time_limit(0);

$path = "$aaPath/";
$dl_file = preg_replace("([^\w\s\d\-_~,;:%\[\]\(\].]|[\.]{2,})", '', $_GET['download_file']);
$fullPath = $path.$dl_file;

if ($fd = fopen ($fullPath, "r")) {
    $fsize = filesize($fullPath);
    $path_parts = pathinfo($fullPath);
    header("Content-type: application/octet-stream");
    header("Content-Disposition: filename=\"".$path_parts["basename"]."\"");
    
    header("Content-length: $fsize");
    header("Cache-control: private");
	ob_flush(); flush();
    while(!feof($fd)) {
        $buffer = fread($fd, 2048);
        echo $buffer;
	ob_flush(); flush();
    }
}
fclose ($fd);
$basename = $path_parts["basename"];
audit ($timestamp, "[AutoAttendant] [Download WAV] $basename", "Downloded WAV File $basename");			
}

if ($mode === 'search') {
	
	$selected = (isset($_REQUEST['selected']) && strlen($_REQUEST['selected']) >=1 ) ? $_REQUEST['selected'] : NULL;
	$currentCompany = (isset($_REQUEST['currentCompany']) && strlen($_REQUEST['currentCompany']) >=2 ) ? $_REQUEST['currentCompany'] : '*';
	$values = '';
	
	if ($selected) {
		switch ($selected) {
		case 'users':
			$queryCn = "cn=users";
			$objectclass = "user";
			$filter = array('cn','telephonenumber');
			break;
		case 'departments':
			$queryCn = "cn=departments";
			$objectclass = "department";
			$filter = array('cn','telephonenumber');
			break;		
		}
		
		$sr=ldap_list($ds, $queryCn,"(&(objectclass=$objectclass)(company=$currentCompany))", $filter);
		$info = ldap_get_entries($ds, $sr);	$selectedEntries = array();
		for ($m=0; $m<$info['count']; $m++) {				
			
		$values .= $info[$m]['telephonenumber'][0] . ":" . $info[$m]['cn'][0] . " (" . $info[$m]['telephonenumber'][0]. ")" . ",";
		}
			$values = rtrim($values, ',');
			echo $values;
	}
}


if ($mode === 'usersdepartments') {
	
	$currentCompany = (isset($_REQUEST['currentCompany']) && strlen($_REQUEST['currentCompany']) >=2 ) ? $_REQUEST['currentCompany'] : '*';
	$users = $departments = array();
	
		$sr=ldap_list($ds, "cn=users","(&(objectclass=user)(company=$currentCompany))", array('cn','telephonenumber','company'));
		$info = ldap_get_entries($ds, $sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$usersCn[$info[$m]['telephonenumber'][0]] = $info[$m]['cn'][0];
		}
				
		$sr=ldap_list($ds, "cn=departments","(&(objectclass=department)(company=$currentCompany))", array('cn','telephonenumber','company'));
		$info = ldap_get_entries($ds, $sr);
		for ($m=0; $m<$info['count']; $m++) {				
			$departmentsCn[$info[$m]['telephonenumber'][0]] = $info[$m]['cn'][0];
		}
				
		$response = array (
			'usersCn' => $usersCn,
			'departmentsCn'  => $departmentsCn
		);
		echo json_encode($response);
	}
	
	
if ($mode === 'wavCheck') {	
	$wavFile = (isset($_REQUEST['wavFile']) && strlen($_REQUEST['wavFile']) >=1) ? $_REQUEST['wavFile'] : NULL;
	$timestamp = time();
	
	$tmp_name = $wavFile;
	$fp = fopen($tmp_name, 'r');
	fseek($fp, 20); $d = fread($fp, 18); $data = unpack('vfmt/vch/Vsr/Vdr/vbs/vbis/vext', $d);
	$format = array(0 => 'error', 1 => 'error', 2 => 'error', 3 => 'error', 4 => 'error', 5 => 'error', 0x0001 => 'PCM',0x0003 => 'IEEE Float',0x0006 => 'A-LAW',0x0007 => 'MuLAW',0xFFFE => 'Extensible',);
	$bit = rtrim($data['sr'],"0") * rtrim($data['dr'],"0");
	$chn = ($data['ch'] = 1) ? "Mono" : "Stereo";

	$result = ($format[$data['fmt']] != "A-LAW" || $data['ch'] !=1 || $data['dr'] !=8000 || $bit !=64) ? 0 : 1;
	echo $result;
	if ($result == 1) {
		$wavFile = basename($wavFile);
		audit ($timestamp, "[AutoAttendant] [Upload WAV] $filename", "WAV File uploaded as $wavFile");			
	}
	
}

?>
